@@ -91,9 +91,14 @@ def get_groups(username=None, user=None):
     group_tool = portal.get_tool('portal_groups')
 
     if user:
-        if not getattr(user, 'portal_groups', None):
-            return []
-        groups = group_tool.getGroupsForPrincipal(user)
+        try:
+            groups = group_tool.getGroupsForPrincipal(user)
+        except AttributeError as e:
+            # Anonymous users from the Zope acl_users folder will fail on this
+            if 'portal_groups' in e.message:
+                return[]
+            raise
+
         return [get(groupname=group) for group in groups]
 
     return group_tool.listGroups()
